@@ -1,18 +1,18 @@
 /*  File src/wtMHproposals.h in package ergm.rank, part of the Statnet suite
- *  of packages for network analysis, http://statnet.org .
+ *  of packages for network analysis, https://statnet.org .
  *
  *  This software is distributed under the GPL-3 license.  It is free,
  *  open source, and has the attribution requirements (GPL Section 7) at
- *  http://statnet.org/attribution
+ *  https://statnet.org/attribution
  *
- *  Copyright 2008-2018 Statnet Commons
+ *  Copyright 2008-2019 Statnet Commons
  */
 #ifndef WTMHPROPOSALS_H
 #define WTMHPROPOSALS_H
 
 #include "wtMHproposal.h"
 
-void MH_AlterSwap(WtMHproposal *MHp, WtNetwork *nwp);
+WtMH_P_FN(MH_AlterSwap);
 
 #endif 
 
